@@ -14,7 +14,6 @@ import os.path as op
 import nibabel as nb
 import numpy as np
 from numpy.polynomial import Legendre
-from scipy import linalg
 
 from .. import config, logging
 from ..external.due import BibTeX
@@ -24,7 +23,17 @@ from ..interfaces.base import (traits, TraitedSpec, BaseInterface,
 from ..utils import NUMPY_MMAP
 from ..utils.misc import normalize_mc_params
 
-IFLOGGER = logging.getLogger('interface')
+IFLOGGER = logging.getLogger('nipype.interface')
+
+
+def fallback_svd(a, full_matrices=True, compute_uv=True):
+    try:
+        return np.linalg.svd(a, full_matrices=full_matrices, compute_uv=compute_uv)
+    except np.linalg.LinAlgError:
+        pass
+
+    from scipy.linalg import svd
+    return svd(a, full_matrices=full_matrices, compute_uv=compute_uv, lapack_driver='gesvd')
 
 
 class ComputeDVARSInputSpec(BaseInterfaceInputSpec):
@@ -272,7 +281,7 @@ class FramewiseDisplacement(BaseInterface):
     .. [Power2012] Power et al., Spurious but systematic correlations in functional
          connectivity MRI networks arise from subject motion, NeuroImage 59(3),
          2012. doi:`10.1016/j.neuroimage.2011.10.018
-         <http://dx.doi.org/10.1016/j.neuroimage.2011.10.018>`_.
+         <https://doi.org/10.1016/j.neuroimage.2011.10.018>`_.
 
 
     """
@@ -327,7 +336,7 @@ Bradley L. and Petersen, Steven E.},
                 tr = self.inputs.series_tr
 
             if self.inputs.normalize and tr is None:
-                IFLOGGER.warn('FD plot cannot be normalized if TR is not set')
+                IFLOGGER.warning('FD plot cannot be normalized if TR is not set')
 
             self._results['out_figure'] = op.abspath(self.inputs.out_figure)
             fig = plot_confound(
@@ -390,13 +399,12 @@ class CompCorInputSpec(BaseInterfaceInputSpec):
         desc='Detrend time series prior to component '
         'extraction')
     use_regress_poly = traits.Bool(
-        True,
         deprecated='0.15.0',
         new_name='pre_filter',
         desc=('use polynomial regression '
               'pre-component extraction'))
     regress_poly_degree = traits.Range(
-        low=1, default=1, usedefault=True, desc='the degree polynomial to use')
+        low=1, value=1, usedefault=True, desc='the degree polynomial to use')
     header_prefix = traits.Str(
         desc=('the desired header for the output tsv '
               'file (one column). If undefined, will '
@@ -414,6 +422,11 @@ class CompCorInputSpec(BaseInterfaceInputSpec):
         low=0,
         usedefault=True,
         desc='Number of volumes at start of series to ignore')
+    failure_mode = traits.Enum(
+        'error', 'NaN',
+        usedefault=True,
+        desc='When no components are found or convergence fails, raise an error '
+             'or silently return columns of NaNs.')
 
 
 class CompCorOutputSpec(TraitedSpec):
@@ -1187,13 +1200,20 @@ def compute_noise_components(imgseries, mask_images, num_components,
 
         # "The covariance matrix C = MMT was constructed and decomposed into its
         # principal components using a singular value decomposition."
-        u, _, _ = linalg.svd(M, full_matrices=False)
+        try:
+            u, _, _ = fallback_svd(M, full_matrices=False)
+        except np.linalg.LinAlgError:
+            if self.inputs.failure_mode == 'error':
+                raise
+            u = np.ones((M.shape[0], num_components), dtype=np.float32) * np.nan
         if components is None:
             components = u[:, :num_components]
         else:
             components = np.hstack((components, u[:, :num_components]))
     if components is None and num_components > 0:
-        raise ValueError('No components found')
+        if self.inputs.failure_mode == 'error':
+            raise ValueError('No components found')
+        components = np.ones((M.shape[0], num_components), dtype=np.float32) * np.nan
     return components, basis
 
 
@@ -1263,12 +1283,12 @@ def _full_rank(X, cmax=1e15):
     X: array of shape(nrows, ncols) after regularization
     cmax=1.e-15, float tolerance for condition number
     """
-    U, s, V = np.linalg.svd(X, 0)
+    U, s, V = fallback_svd(X, full_matrices=False)
     smax, smin = s.max(), s.min()
     c = smax / smin
     if c < cmax:
         return X, c
-    IFLOGGER.warn('Matrix is singular at working precision, regularizing...')
+    IFLOGGER.warning('Matrix is singular at working precision, regularizing...')
     lda = (smax - cmax * smin) / (cmax - 1)
     s = s + lda
     X = np.dot(U, np.dot(np.diag(s), V))
