@@ -1,31 +1,21 @@
+# -*- coding: utf-8 -*-
 """Provides interfaces to various commands provided by dcmstack
-
-   Change directory to provide relative paths for doctests
-   >>> import os
-   >>> filepath = os.path.dirname( os.path.realpath( __file__ ) )
-   >>> datadir = os.path.realpath(os.path.join(filepath, '../testing/data'))
-   >>> os.chdir(datadir)
-
 """
+from __future__ import (print_function, division, unicode_literals,
+                        absolute_import)
 
-from __future__ import absolute_import
 import os
+from os import path as op
 import string
 import errno
-from os import path as op
 from glob import glob
-from nipype.interfaces.base import (TraitedSpec,
-                                    DynamicTraitedSpec,
-                                    InputMultiPath,
-                                    File,
-                                    Directory,
-                                    traits,
-                                    BaseInterface,
-                                   )
+
 import nibabel as nb
-from nipype.interfaces.traits_extension import isdefined, Undefined
 import imghdr
-from nipype.external import six
+
+from .base import (TraitedSpec, DynamicTraitedSpec, InputMultiPath, File,
+                   Directory, traits, BaseInterface, isdefined, Undefined)
+from ..utils import NUMPY_MMAP
 
 have_dcmstack = True
 try:
@@ -39,7 +29,7 @@ except ImportError:
 def sanitize_path_comp(path_comp):
     result = []
     for char in path_comp:
-        if not char in string.letters + string.digits + '-_.':
+        if char not in string.letters + string.digits + '-_.':
             result.append('_')
         else:
             result.append(char)
@@ -49,23 +39,25 @@ def sanitize_path_comp(path_comp):
 class NiftiGeneratorBaseInputSpec(TraitedSpec):
     out_format = traits.Str(desc="String which can be formatted with "
                             "meta data to create the output filename(s)")
-    out_ext = traits.Str('.nii.gz', usedefault=True,
-                         desc="Determines output file type")
-    out_path = Directory(desc='output path, current working directory if not set')
+    out_ext = traits.Str(
+        '.nii.gz', usedefault=True, desc="Determines output file type")
+    out_path = Directory(
+        desc='output path, current working directory if not set')
 
 
 class NiftiGeneratorBase(BaseInterface):
     '''Base class for interfaces that produce Nifti files, potentially with
     embedded meta data.'''
+
     def _get_out_path(self, meta, idx=None):
         '''Return the output path for the gernerated Nifti.'''
         if self.inputs.out_format:
             out_fmt = self.inputs.out_format
         else:
-            #If no out_format is specified, use a sane default that will work
-            #with the provided meta data.
+            # If no out_format is specified, use a sane default that will work
+            # with the provided meta data.
             out_fmt = []
-            if not idx is None:
+            if idx is not None:
                 out_fmt.append('%03d' % idx)
             if 'SeriesNumber' in meta:
                 out_fmt.append('%(SeriesNumber)03d')
@@ -96,17 +88,20 @@ class NiftiGeneratorBase(BaseInterface):
 
 
 class DcmStackInputSpec(NiftiGeneratorBaseInputSpec):
-    dicom_files = traits.Either(InputMultiPath(File(exists=True)),
-                                Directory(exists=True),
-                                traits.Str(),
-                                mandatory=True)
+    dicom_files = traits.Either(
+        InputMultiPath(File(exists=True)),
+        Directory(exists=True),
+        traits.Str(),
+        mandatory=True)
     embed_meta = traits.Bool(desc="Embed DICOM meta data into result")
     exclude_regexes = traits.List(desc="Meta data to exclude, suplementing "
                                   "any default exclude filters")
     include_regexes = traits.List(desc="Meta data to include, overriding any "
                                   "exclude filters")
-    force_read = traits.Bool(True, usedefault=True,
-                             desc=('Force reading files without DICM marker'))
+    force_read = traits.Bool(
+        True,
+        usedefault=True,
+        desc=('Force reading files without DICM marker'))
 
 
 class DcmStackOutputSpec(TraitedSpec):
@@ -131,7 +126,7 @@ class DcmStack(NiftiGeneratorBase):
     output_spec = DcmStackOutputSpec
 
     def _get_filelist(self, trait_input):
-        if isinstance(trait_input, six.string_types):
+        if isinstance(trait_input, (str, bytes)):
             if op.isdir(trait_input):
                 return glob(op.join(trait_input, '*.dcm'))
             else:
@@ -151,8 +146,9 @@ class DcmStack(NiftiGeneratorBase):
                                                      include_regexes)
         stack = dcmstack.DicomStack(meta_filter=meta_filter)
         for src_path in src_paths:
-            if not imghdr.what(src_path)=="gif":
-                src_dcm = dicom.read_file(src_path, force=self.inputs.force_read)
+            if not imghdr.what(src_path) == "gif":
+                src_dcm = dicom.read_file(
+                    src_path, force=self.inputs.force_read)
                 stack.add_dcm(src_dcm)
         nii = stack.to_nifti(embed_meta=True)
         nw = NiftiWrapper(nii)
@@ -184,10 +180,10 @@ class GroupAndStack(DcmStack):
         stacks = dcmstack.parse_and_stack(src_paths)
 
         self.out_list = []
-        for key, stack in stacks.iteritems():
+        for key, stack in list(stacks.items()):
             nw = NiftiWrapper(stack.to_nifti(embed_meta=True))
             const_meta = nw.meta_ext.get_class_dict(('global', 'const'))
-            out_path =  self._get_out_path(const_meta)
+            out_path = self._get_out_path(const_meta)
             if not self.inputs.embed_meta:
                 nw.remove_extension()
             nb.save(nw.nii_img, out_path)
@@ -202,16 +198,15 @@ class GroupAndStack(DcmStack):
 
 
 class LookupMetaInputSpec(TraitedSpec):
-    in_file = File(mandatory=True,
-                   exists=True,
-                   desc='The input Nifti file')
-    meta_keys = traits.Either(traits.List(),
-                              traits.Dict(),
-                              mandatory=True,
-                              desc=("List of meta data keys to lookup, or a "
-                              "dict where keys specify the meta data keys to "
-                              "lookup and the values specify the output names")
-                             )
+    in_file = File(mandatory=True, exists=True, desc='The input Nifti file')
+    meta_keys = traits.Either(
+        traits.List(),
+        traits.Dict(),
+        mandatory=True,
+        desc=("List of meta data keys to lookup, or a "
+              "dict where keys specify the meta data "
+              "keys to lookup and the values specify "
+              "the output names"))
 
 
 class LookupMeta(BaseInterface):
@@ -246,12 +241,12 @@ class LookupMeta(BaseInterface):
         self._make_name_map()
         outputs = super(LookupMeta, self)._outputs()
         undefined_traits = {}
-        for out_name in self._meta_keys.values():
+        for out_name in list(self._meta_keys.values()):
             outputs.add_trait(out_name, traits.Any)
             undefined_traits[out_name] = Undefined
         outputs.trait_set(trait_change_notify=False, **undefined_traits)
         # Not sure why this is needed
-        for out_name in self._meta_keys.values():
+        for out_name in list(self._meta_keys.values()):
             _ = getattr(outputs, out_name)
         return outputs
 
@@ -260,7 +255,7 @@ class LookupMeta(BaseInterface):
         self._make_name_map()
         nw = NiftiWrapper.from_filename(self.inputs.in_file)
         self.result = {}
-        for meta_key, out_name in self._meta_keys.iteritems():
+        for meta_key, out_name in list(self._meta_keys.items()):
             self.result[out_name] = nw.meta_ext.get_values(meta_key)
 
         return runtime
@@ -298,26 +293,26 @@ class CopyMeta(BaseInterface):
         dest = NiftiWrapper(dest_nii, make_empty=True)
         classes = src.meta_ext.get_valid_classes()
         if self.inputs.include_classes:
-            classes = [cls
-                       for cls in classes
-                       if cls in self.inputs.include_classes
-                      ]
+            classes = [
+                cls for cls in classes if cls in self.inputs.include_classes
+            ]
         if self.inputs.exclude_classes:
-            classes = [cls
-                       for cls in classes
-                       if not cls in self.inputs.exclude_classes
-                      ]
+            classes = [
+                cls for cls in classes
+                if cls not in self.inputs.exclude_classes
+            ]
 
         for cls in classes:
             src_dict = src.meta_ext.get_class_dict(cls)
             dest_dict = dest.meta_ext.get_class_dict(cls)
             dest_dict.update(src_dict)
-        # Update the shape and slice dimension to reflect the meta extension update.
+        # Update the shape and slice dimension to reflect the meta extension
+        # update.
         dest.meta_ext.slice_dim = src.meta_ext.slice_dim
         dest.meta_ext.shape = src.meta_ext.shape
 
-        self.out_path = op.join(os.getcwd(),
-                                  op.basename(self.inputs.dest_file))
+        self.out_path = op.join(os.getcwd(), op.basename(
+            self.inputs.dest_file))
         dest.to_filename(self.out_path)
 
         return runtime
@@ -329,12 +324,12 @@ class CopyMeta(BaseInterface):
 
 
 class MergeNiftiInputSpec(NiftiGeneratorBaseInputSpec):
-    in_files = traits.List(mandatory=True,
-                           desc="List of Nifti files to merge")
-    sort_order = traits.Either(traits.Str(),
-                               traits.List(),
-                               desc="One or more meta data keys to "
-                               "sort files by.")
+    in_files = traits.List(mandatory=True, desc="List of Nifti files to merge")
+    sort_order = traits.Either(
+        traits.Str(),
+        traits.List(),
+        desc="One or more meta data keys to "
+        "sort files by.")
     merge_dim = traits.Int(desc="Dimension to merge along. If not "
                            "specified, the last singular or "
                            "non-existant dimension is used.")
@@ -359,15 +354,11 @@ class MergeNifti(NiftiGeneratorBase):
     output_spec = MergeNiftiOutputSpec
 
     def _run_interface(self, runtime):
-        niis = [nb.load(fn)
-                for fn in self.inputs.in_files
-               ]
-        nws = [NiftiWrapper(nii, make_empty=True)
-               for nii in niis
-              ]
+        niis = [nb.load(fn, mmap=NUMPY_MMAP) for fn in self.inputs.in_files]
+        nws = [NiftiWrapper(nii, make_empty=True) for nii in niis]
         if self.inputs.sort_order:
             sort_order = self.inputs.sort_order
-            if isinstance(sort_order, six.string_types):
+            if isinstance(sort_order, (str, bytes)):
                 sort_order = [sort_order]
             nws.sort(key=make_key_func(sort_order))
         if self.inputs.merge_dim == traits.Undefined:
@@ -393,8 +384,7 @@ class SplitNiftiInputSpec(NiftiGeneratorBaseInputSpec):
 
 
 class SplitNiftiOutputSpec(TraitedSpec):
-    out_list = traits.List(File(exists=True),
-                           desc="Split Nifti files")
+    out_list = traits.List(File(exists=True), desc="Split Nifti files")
 
 
 class SplitNifti(NiftiGeneratorBase):
@@ -426,4 +416,3 @@ class SplitNifti(NiftiGeneratorBase):
         outputs = self._outputs().get()
         outputs['out_list'] = self.out_list
         return outputs
-
