@@ -1,48 +1,81 @@
 # -*- coding: utf-8 -*-
-from __future__ import print_function, division, unicode_literals, absolute_import
+from __future__ import (print_function, division, unicode_literals,
+                        absolute_import)
 from builtins import str, bytes
 
 import os.path as op
 import glob
 
 from ... import logging
-from ...utils.filemanip import list_to_filename
+from ...utils.filemanip import simplify_list
 from ..base import (traits, File, Directory, TraitedSpec, OutputMultiPath)
 from ..freesurfer.base import FSCommand, FSTraitedSpec
 
-iflogger = logging.getLogger('interface')
+iflogger = logging.getLogger('nipype.interface')
 
 
 class WatershedBEMInputSpec(FSTraitedSpec):
-    subject_id = traits.Str(argstr='--subject %s', mandatory=True,
-                            desc='Subject ID (must have a complete Freesurfer directory)')
-    subjects_dir = Directory(exists=True, mandatory=True, usedefault=True,
-                             desc='Path to Freesurfer subjects directory')
-    volume = traits.Enum('T1', 'aparc+aseg', 'aseg', 'brain', 'orig', 'brainmask', 'ribbon',
-                         argstr='--volume %s', usedefault=True,
-                         desc='The volume from the "mri" directory to use (defaults to T1)')
-    overwrite = traits.Bool(True, usedefault=True, argstr='--overwrite',
-                            desc='Overwrites the existing files')
-    atlas_mode = traits.Bool(argstr='--atlas',
-                             desc='Use atlas mode for registration (default: no rigid alignment)')
+    subject_id = traits.Str(
+        argstr='--subject %s',
+        mandatory=True,
+        desc='Subject ID (must have a complete Freesurfer directory)')
+    subjects_dir = Directory(
+        exists=True,
+        mandatory=True,
+        usedefault=True,
+        desc='Path to Freesurfer subjects directory')
+    volume = traits.Enum(
+        'T1',
+        'aparc+aseg',
+        'aseg',
+        'brain',
+        'orig',
+        'brainmask',
+        'ribbon',
+        argstr='--volume %s',
+        usedefault=True,
+        desc='The volume from the "mri" directory to use (defaults to T1)')
+    overwrite = traits.Bool(
+        True,
+        usedefault=True,
+        argstr='--overwrite',
+        desc='Overwrites the existing files')
+    atlas_mode = traits.Bool(
+        argstr='--atlas',
+        desc='Use atlas mode for registration (default: no rigid alignment)')
 
 
 class WatershedBEMOutputSpec(TraitedSpec):
-    mesh_files = OutputMultiPath(File(exists=True),
-                                 desc=('Paths to the output meshes (brain, inner '
-                                       'skull, outer skull, outer skin)'))
-    brain_surface = File(exists=True, loc='bem/watershed',
-                         desc='Brain surface (in Freesurfer format)')
-    inner_skull_surface = File(exists=True, loc='bem/watershed',
-                               desc='Inner skull surface (in Freesurfer format)')
-    outer_skull_surface = File(exists=True, loc='bem/watershed',
-                               desc='Outer skull surface (in Freesurfer format)')
-    outer_skin_surface = File(exists=True, loc='bem/watershed',
-                              desc='Outer skin surface (in Freesurfer format)')
-    fif_file = File(exists=True, loc='bem', altkey='fif',
-                    desc='"fif" format file for EEG processing in MNE')
-    cor_files = OutputMultiPath(File(exists=True), loc='bem/watershed/ws',
-                                altkey='COR', desc='"COR" format files')
+    mesh_files = OutputMultiPath(
+        File(exists=True),
+        desc=('Paths to the output meshes (brain, inner '
+              'skull, outer skull, outer skin)'))
+    brain_surface = File(
+        exists=True,
+        loc='bem/watershed',
+        desc='Brain surface (in Freesurfer format)')
+    inner_skull_surface = File(
+        exists=True,
+        loc='bem/watershed',
+        desc='Inner skull surface (in Freesurfer format)')
+    outer_skull_surface = File(
+        exists=True,
+        loc='bem/watershed',
+        desc='Outer skull surface (in Freesurfer format)')
+    outer_skin_surface = File(
+        exists=True,
+        loc='bem/watershed',
+        desc='Outer skin surface (in Freesurfer format)')
+    fif_file = File(
+        exists=True,
+        loc='bem',
+        altkey='fif',
+        desc='"fif" format file for EEG processing in MNE')
+    cor_files = OutputMultiPath(
+        File(exists=True),
+        loc='bem/watershed/ws',
+        altkey='COR',
+        desc='"COR" format files')
 
 
 class WatershedBEM(FSCommand):
@@ -87,7 +120,7 @@ class WatershedBEM(FSCommand):
                                       output_traits.traits()[k].loc,
                                       output_traits.traits()[k].altkey)
                 if val:
-                    value_list = list_to_filename(val)
+                    value_list = simplify_list(val)
                     if isinstance(value_list, list):
                         out_files = []
                         for value in value_list:
