@@ -39,8 +39,8 @@ class FitTensorInputSpec(MRTrix3BaseInputSpec):
         argstr='-method %s',
         desc=('select method used to perform the fitting'))
     reg_term = traits.Float(
-        5.e3,
         argstr='-regularisation %f',
+        max_ver='0.3.13',
         desc=('specify the strength of the regularisation term on the '
               'magnitude of the tensor elements (default = 5000). This '
               'only applies to the non-linear methods'))
@@ -102,9 +102,11 @@ class EstimateFODInputSpec(MRTrix3BaseInputSpec):
         mandatory=True,
         desc='output WM ODF')
     gm_txt = File(argstr='%s', position=-4, desc='GM response text file')
-    gm_odf = File('gm.mif', argstr='%s', position=-3, desc='output GM ODF')
+    gm_odf = File('gm.mif', usedefault=True, argstr='%s',
+                  position=-3, desc='output GM ODF')
     csf_txt = File(argstr='%s', position=-2, desc='CSF response text file')
-    csf_odf = File('csf.mif', argstr='%s', position=-1, desc='output CSF ODF')
+    csf_odf = File('csf.mif', usedefault=True, argstr='%s',
+                   position=-1, desc='output CSF ODF')
     mask_file = File(exists=True, argstr='-mask %s', desc='mask image')
 
     # DW Shell selection options
@@ -114,7 +116,7 @@ class EstimateFODInputSpec(MRTrix3BaseInputSpec):
         argstr='-shell %s',
         desc='specify one or more dw gradient shells')
     max_sh = traits.Int(
-        8,
+        8, usedefault=True,
         argstr='-lmax %d',
         desc='maximum harmonic degree of response function')
     in_dirs = File(
@@ -146,7 +148,7 @@ class EstimateFOD(MRTrix3Base):
     >>> fod.inputs.wm_txt = 'wm.txt'
     >>> fod.inputs.grad_fsl = ('bvecs', 'bvals')
     >>> fod.cmdline                               # doctest: +ELLIPSIS
-    'dwi2fod -fslgrad bvecs bvals csd dwi.mif wm.txt wm.mif'
+    'dwi2fod -fslgrad bvecs bvals -lmax 8 csd dwi.mif wm.txt wm.mif gm.mif csf.mif'
     >>> fod.run()                                 # doctest: +SKIP
     """
 
