@@ -182,7 +182,8 @@ class TensorMetricsInputSpec(CommandLineInputSpec):
     out_eval = File(
         argstr='-value %s', desc='output selected eigenvalue(s) file')
     component = traits.List(
-        [1, 2, 3],
+        [1],
+        usedefault=True,
         argstr='-num %s',
         sep=',',
         desc=('specify the desired eigenvalue/eigenvector(s). Note that '
@@ -221,7 +222,7 @@ class TensorMetrics(CommandLine):
     >>> comp.inputs.in_file = 'dti.mif'
     >>> comp.inputs.out_fa = 'fa.mif'
     >>> comp.cmdline                               # doctest: +ELLIPSIS
-    'tensor2metric -fa fa.mif dti.mif'
+    'tensor2metric -num 1 -fa fa.mif dti.mif'
     >>> comp.run()                                 # doctest: +SKIP
     """
 
@@ -266,7 +267,6 @@ class ComputeTDIInputSpec(CommandLineInputSpec):
         desc='specify output image data type')
     use_dec = traits.Bool(argstr='-dec', desc='perform mapping in DEC space')
     dixel = File(
-        'dixels.txt',
         argstr='-dixel %s',
         desc='map streamlines to'
         'dixels within each voxel. Directions are stored as'
@@ -503,7 +503,7 @@ class DWIExtractInputSpec(MRTrix3BaseInputSpec):
     out_file = File(
         argstr='%s', mandatory=True, position=-1, desc='output image')
     bzero = traits.Bool(argstr='-bzero', desc='extract b=0 volumes')
-    nobzero = traits.Bool(argstr='-nobzero', desc='extract non b=0 volumes')
+    nobzero = traits.Bool(argstr='-no_bzero', desc='extract non b=0 volumes')
     singleshell = traits.Bool(
         argstr='-singleshell', desc='extract volumes with a specific shell')
     shell = traits.List(
