@@ -16,11 +16,10 @@ standard_library.install_aliases()
 import os
 import re
 import numpy as np
-import nibabel as nb
 
 from ..base import (traits, TraitedSpec, DynamicTraitedSpec, File, Undefined,
                     isdefined, OutputMultiPath, InputMultiPath, BaseInterface,
-                    BaseInterfaceInputSpec, Str)
+                    BaseInterfaceInputSpec, Str, SimpleInterface)
 from ..io import IOBase, add_traits
 from ...utils.filemanip import ensure_list, copyfile, split_filename
 
@@ -204,7 +203,6 @@ class Merge(IOBase):
 
 
 class RenameInputSpec(DynamicTraitedSpec):
-
     in_file = File(exists=True, mandatory=True, desc="file to rename")
     keep_ext = traits.Bool(
         desc=("Keep in_file extension, replace "
@@ -218,12 +216,11 @@ class RenameInputSpec(DynamicTraitedSpec):
 
 
 class RenameOutputSpec(TraitedSpec):
-
     out_file = traits.File(
         exists=True, desc="softlink to original file with new name")
 
 
-class Rename(IOBase):
+class Rename(SimpleInterface, IOBase):
     """Change the name of a file based on a mapped format string.
 
     To use additional inputs that will be defined at run-time, the class
@@ -303,15 +300,11 @@ class Rename(IOBase):
 
     def _run_interface(self, runtime):
         runtime.returncode = 0
-        _ = copyfile(self.inputs.in_file,
-                     os.path.join(os.getcwd(), self._rename()))
+        out_file = os.path.join(runtime.cwd, self._rename())
+        _ = copyfile(self.inputs.in_file, out_file)
+        self._results['out_file'] = out_file
         return runtime
 
-    def _list_outputs(self):
-        outputs = self._outputs().get()
-        outputs["out_file"] = os.path.join(os.getcwd(), self._rename())
-        return outputs
-
 
 class SplitInputSpec(BaseInterfaceInputSpec):
     inlist = traits.List(
@@ -422,7 +415,7 @@ class AssertEqual(BaseInterface):
     input_spec = AssertEqualInputSpec
 
     def _run_interface(self, runtime):
-
+        import nibabel as nb
         data1 = nb.load(self.inputs.volume1).get_data()
         data2 = nb.load(self.inputs.volume2).get_data()
 
