@@ -3,7 +3,8 @@
 # vi: set ft=python sts=4 ts=4 sw=4 et:
 """Parallel workflow execution via IPython controller
 """
-from __future__ import print_function, division, unicode_literals, absolute_import
+from __future__ import (print_function, division, unicode_literals,
+                        absolute_import)
 
 from future import standard_library
 standard_library.install_aliases()
@@ -22,7 +23,6 @@ except:
     IPython_not_loaded = True
 
 
-
 def execute_task(pckld_task, node_config, updatehash):
     from socket import gethostname
     from traceback import format_exc
@@ -39,6 +39,8 @@ def execute_task(pckld_task, node_config, updatehash):
         result = task.run(updatehash=updatehash)
     except:
         traceback = format_exc()
+        from pickle import loads
+        task = loads(pckld_task)
         result = task.result
     os.chdir(cwd)
     return result, traceback, gethostname()
@@ -55,8 +57,10 @@ class IPythonPlugin(DistributedPluginBase):
         valid_args = ('url_file', 'profile', 'cluster_id', 'context', 'debug',
                       'timeout', 'config', 'username', 'sshserver', 'sshkey',
                       'password', 'paramiko')
-        self.client_args = {arg: plugin_args[arg]
-                            for arg in valid_args if arg in plugin_args}
+        self.client_args = {
+            arg: plugin_args[arg]
+            for arg in valid_args if arg in plugin_args
+        }
         self.iparallel = None
         self.taskclient = None
         self.taskmap = {}
@@ -72,20 +76,24 @@ class IPythonPlugin(DistributedPluginBase):
             __import__(name)
             self.iparallel = sys.modules[name]
         except ImportError as e:
-            raise_from(ImportError("ipyparallel not found. Parallel execution "
-                                   "will be unavailable"), e)
+            raise_from(
+                ImportError("ipyparallel not found. Parallel execution "
+                            "will be unavailable"), e)
         try:
             self.taskclient = self.iparallel.Client(**self.client_args)
         except Exception as e:
             if isinstance(e, TimeoutError):
                 raise_from(Exception("No IPython clients found."), e)
             if isinstance(e, IOError):
-                raise_from(Exception("ipcluster/ipcontroller has not been started"), e)
+                raise_from(
+                    Exception("ipcluster/ipcontroller has not been started"),
+                    e)
             if isinstance(e, ValueError):
                 raise_from(Exception("Ipython kernel not installed"), e)
             else:
                 raise e
-        return super(IPythonPlugin, self).run(graph, config, updatehash=updatehash)
+        return super(IPythonPlugin, self).run(
+            graph, config, updatehash=updatehash)
 
     def _get_result(self, taskid):
         if taskid not in self.taskmap:
@@ -102,10 +110,8 @@ class IPythonPlugin(DistributedPluginBase):
 
     def _submit_job(self, node, updatehash=False):
         pckld_node = dumps(node, 2)
-        result_object = self.taskclient.load_balanced_view().apply(execute_task,
-                                                                   pckld_node,
-                                                                   node.config,
-                                                                   updatehash)
+        result_object = self.taskclient.load_balanced_view().apply(
+            execute_task, pckld_node, node.config, updatehash)
         self._taskid += 1
         self.taskmap[self._taskid] = result_object
         return self._taskid
@@ -114,8 +120,7 @@ class IPythonPlugin(DistributedPluginBase):
         if result and result['traceback']:
             node._result = result['result']
             node._traceback = result['traceback']
-            return report_crash(node,
-                                traceback=result['traceback'])
+            return report_crash(node, traceback=result['traceback'])
         else:
             return report_crash(node)
 
