@@ -1,13 +1,15 @@
 """Parallel workflow execution via PBS/Torque
 """
+from __future__ import (print_function, division, unicode_literals,
+                        absolute_import)
+from builtins import open
 
 import os
 import sys
 
-from .base import (GraphPluginBase, logger)
-
 from ...interfaces.base import CommandLine
 from .sgegraph import SGEGraphPlugin
+from .base import logger
 
 
 class PBSGraphPlugin(SGEGraphPlugin):
@@ -32,13 +34,13 @@ class PBSGraphPlugin(SGEGraphPlugin):
             fp.writelines('#!/usr/bin/env sh\n')
             for idx, pyscript in enumerate(pyfiles):
                 node = nodes[idx]
-                template, qsub_args = self._get_args(
-                    node, ["template", "qsub_args"])
+                template, qsub_args = self._get_args(node,
+                                                     ["template", "qsub_args"])
 
                 batch_dir, name = os.path.split(pyscript)
                 name = '.'.join(name.split('.')[:-1])
-                batchscript = '\n'.join((template,
-                                         '%s %s' % (sys.executable, pyscript)))
+                batchscript = '\n'.join((template, '%s %s' % (sys.executable,
+                                                              pyscript)))
                 batchscriptfile = os.path.join(batch_dir,
                                                'batchscript_%s.sh' % name)
                 with open(batchscriptfile, 'wt') as batchfp:
@@ -46,15 +48,18 @@ class PBSGraphPlugin(SGEGraphPlugin):
                     batchfp.close()
                 deps = ''
                 if idx in dependencies:
-                    values = ['$job%05d' %
-                              jobid for jobid in dependencies[idx]]
+                    values = [
+                        '$job%05d' % jobid for jobid in dependencies[idx]
+                    ]
                     if len(values):
                         deps = '-W depend=afterok:%s' % ':'.join(values)
-                fp.writelines('job%05d=`qsub %s %s %s`\n' % (idx, deps,
-                                                             qsub_args,
-                                                             batchscriptfile))
-        cmd = CommandLine('sh', environ=os.environ.data,
-                          terminal_output='allatonce')
+                fp.writelines('job%05d=`qsub %s %s %s`\n' %
+                              (idx, deps, qsub_args, batchscriptfile))
+        cmd = CommandLine(
+            'sh',
+            environ=dict(os.environ),
+            resource_monitor=False,
+            terminal_output='allatonce')
         cmd.inputs.args = '%s' % submitjobsfile
         cmd.run()
         logger.info('submitted all jobs to queue')
